mod crt {

    pub fn public(filename: String) -> Vec<u8> {
        /*error supressor */
        return vec![1, 2, 3];
    }
    pub fn private(filename: String) -> Vec<u8> {
        /* error suppressor */
        return vec![1, 2, 3];
    }
}
